************
Introduction
************

This is a software development kit (SDK) to:

* manipulate,
* verify, and
* de/serialize to and from JSON and XML

... Asset Administration Shells based on `the version 3.1 of the meta-model`_.

.. _the version 3.1 of the meta-model: https://industrialdigitaltwin.org/content-hub/aasspecifications

For a brief introduction, see :doc:`Getting Started <getting_started/index>`.

For a detailed documentation of the API, see :doc:`API <api/index>`.

We document some of the design decisions in: :doc:`Design Decisions <design_decisions>`.
